<?php


if (!class_exists("AgeGatePlugin")) {
	class AgeGateBase {
		
		var $plugin_url;
		var $plugin_path;
		var $is_wp = false;
		var $protection_done = false;
		
		function __construct( $is_wp ) {
			if (!session_id()) session_start();
			
			$this->is_wp = $is_wp;
			$this->plugin_url = $this->plugin_dir_url(__FILE__);
			$this->plugin_path = $this->plugin_dir_path(__FILE__);
			
			$this->register_script('jquery', $this->plugin_url. 'jquery/js/jquery-1.6.2.min.js');
			
			$this->add_action('admin_menu', array( &$this, 'admin_menu'));
			$this->add_action('admin_init', array( &$this, 'admin_init'));
			$this->add_action('wp_ajax_agegate_save_preview', array( &$this, 'save_preview'));
			$this->add_action('wp_ajax_agegate_show_preview', array( &$this, 'show_preview'));
			$this->add_action('wp_ajax_agegate_code', array( &$this, 'code'));
			$this->add_action('wp_ajax_nopriv_agegate_window', array( &$this, 'show_window'));
			$this->add_action('wp_ajax_agegate_window', array( &$this, 'show_window'));
			
			$this->add_action('wp_head', array( &$this, 'protect'));
			$this->add_action('get_header', array( &$this, 'protect_styles'));
			
			$this->add_action('add_meta_boxes', array( &$this, 'post_box'));
			$this->add_action('save_post', array( &$this, 'save_post'));
		}
		
		function post_box(){
			if(current_user_can('edit_pages')) // Editors+ Only
				add_meta_box( 'agegate_override', 'Age gate', array( &$this, 'edit_post'), 'page', 'side');
		}
		
		function edit_post(){
			$options = $this->get_options();
			global $post;
			$meta = get_post_meta($post->ID, 'agegate', true);
			?>
				<div class="option_wrap">
			        <p>Show the age gate on this page ?</p>
			        <p>
			        	<input type="radio" name="agegate" value="" <?php checked($meta, "", true); ?>/> <label for="agegate">Only if enabled globally</label><br />
			        	<input type="radio" name="agegate" value="1" <?php checked($meta, 1, true); ?>/> <label for="agegate">Yes</label><br />
			        	<input type="radio" name="agegate" value="2" <?php checked($meta, 2, true); ?>/> <label for="agegate">No</label>
			        </p>
			    </div>  
			<?php
		}
		
		function save_post() {
			global $post;
			$postID = $post->ID;
			$postType = $post->post_type;
			
			if($postType == 'page' && !current_user_can('edit_pages')) return FALSE;
			
			if($postType == 'page') {
				update_post_meta($postID, 'agegate', $_POST['agegate']);
			}
		}
		
		/* PROTECT PAGES ********************************************************************/
		
		function must_protect() {
			if (isset($_COOKIE['agegate'])) return false;
			$options = $this->get_options();
			
			if (!$options['enabled']) return false;
			if ($this->is_feed()) return false;
			if ($this->is_plugin_url()) return false;
			if ($this->is_wp) {
				global $post;
				$meta = get_post_meta($post->ID, 'agegate', true);
				if ($meta==2) return false;
				if ($meta==1) return true;
				return $options['enabled_globally'];
			}
			return true;
		}
		
		function protect_styles() {
			//if (!$this->must_protect()) return FALSE;
			$this->register_style('shadowbox', $this->plugin_url. 'shadowbox/shadowbox.css');
			$this->register_script('shadowbox', $this->plugin_url. 'shadowbox/shadowbox.js', array('jquery'));
			$this->enqueue_script('shadowbox');
			$this->enqueue_style('shadowbox');
		}
		
		function protect() {
			if (!$this->must_protect()) return FALSE;
			if ($this->protection_done) return FALSE;
			$this->protection_done = true;
			$options = $this->get_options();
			?>
	<!-- AGE GATE PROTECTION -->
	<script type="text/javascript"><!-- 
	Shadowbox.init({
		handleOversize: 'resize',
		overlayColor:'#000000',
		overlayOpacity: '0.9',
		modal: true,
		players: ['iframe'],
		onOpen: function() { document.body.style.overflow = "hidden"; return true; },
		onClose: function() { document.body.style.overflow = "auto"; return false; }
	});
	window.onload = function() {
	    jQuery('#sb-body').css('background-color',"<?php echo $options['window_color'] ?>");
	    Shadowbox.open({
			content:    "<?php echo $this->admin_url('admin-ajax.php').'?action=agegate_window' ?>",
			player:     "iframe",
			title:      "<?php echo $options['title'] ?>",
			height:     <?php echo $options['height'] ?>,
			width:      <?php echo $options['width'] ?>
	    });
	};
	function close_shadowbox() {
		Shadowbox.close();
	}
	--></script>
	<!-- END AGE GATE PROTECTION -->
			<?php 
		}
		
		function show_window() {
			$options = $this->get_options();
			$plugin_url = $this->plugin_url;
			$is_preview = false;
			$countries = array();
			$cc = explode("\n", $options['minimum_age']);
			foreach($cc as $c) {
				$ca = explode(":", $c);
				$countries[] = array("age"=>$ca[0], "name" =>$ca[1]);
			}
			$cookie_url = $this->admin_url('admin-ajax.php').'?action=agegate_cookie';
			include ($this->plugin_path.'window.php');
			die();
		}
		
		
		
		/* PLUGIN ADMIN FUNCTIONS ********************************************************************/
		
		function admin_menu() {
			$page = $this->add_menu_page('Age Gate', 'Age Gate', 'manage_options', 'agegate', null);
			$subpage1 = $this->add_submenu_page( 'agegate', 'Age Gate - General settings', 'General settings', 'manage_options', 'agegate', array( &$this, 'general_settings'));
			$subpage2 = $this->add_submenu_page( 'agegate', 'Age Gate - Window settings', 'Window settings', 'manage_options', 'agegate_window_settings', array( &$this, 'window_settings'));
			$this->add_action('admin_print_styles-' . $subpage1, array( &$this, 'admin_style'));
			$this->add_action('admin_print_styles-' . $subpage2, array( &$this, 'admin_style'));
		}
		
		function admin_init() {
			$this->register_style('agegate_admin_css', $this->plugin_url. 'css/admin.css');
			$this->register_style('agegate_colorpicker_css', $this->plugin_url. 'farbtastic/farbtastic.css');
			$this->register_script('agegate_admin_js', $this->plugin_url. 'js/admin.js', array('jquery'));
			$this->register_script('agegate_uploader_js', $this->plugin_url. 'js/imageupload.js', array('jquery'));
			$this->register_script('agegate_colorpicker_js', $this->plugin_url. 'farbtastic/farbtastic.js', array('jquery'));
			$this->register_style('shadowbox', $this->plugin_url. 'shadowbox/shadowbox.css');
			$this->register_script('shadowbox', $this->plugin_url. 'shadowbox/shadowbox.js', array('jquery'));
			
		}
		
		function admin_style(){
			$this->enqueue_style('agegate_colorpicker_css');
			$this->enqueue_script('agegate_colorpicker_js');
			$this->enqueue_script('agegate_uploader_js');
			$this->enqueue_script('shadowbox');
			$this->enqueue_style('shadowbox');
			$this->enqueue_style('agegate_admin_css');
			$this->enqueue_script('agegate_admin_js');
			$options = $this->get_options();
			$this->localize_script('agegate_admin_js', 'agegate_params', array(
				'window_color' => $options['window_color'],
				'width' => $options['width'],
				'height' => $options['height'],
				'title' => $options['title'],
				'image_upload_url' => $this->plugin_url."imageupload.php",
				'preview_show_url' => $this->admin_url('admin-ajax.php').'?action=agegate_show_preview',
				'preview_save_url' => $this->admin_url('admin-ajax.php').'?action=agegate_save_preview',
				'code_url' => $this->admin_url('admin-ajax.php').'?action=agegate_code'
			));
		}
		

		/* general settings admin ********************************************************************/

		function general_settings()
		{
			if (isset($_POST['agegate_save_general_settings'])) {
				$this->save_options_and_redirect();
			}
			$message = $this->session_get('message', true);
			$options = $this->get_options();
			$plugin_url = $this->plugin_url;
			$save_url = $this->remove_query_arg(array());
			$preview_show_url = $this->admin_url('admin-ajax.php').'?action=agegate_preview';
			$preview_save_url = $this->admin_url('admin-ajax.php');
			$code_url = $this->admin_url('admin-ajax.php').'?action=agegate_code';
			$is_wp = $this->is_wp;
			include ($this->plugin_path.'settings_general.php');
		}
		
		
		
		/* window settings admin ********************************************************************/
		
		function window_settings()
		{
			if (isset($_POST['agegate_save_window_settings'])) {
				$this->save_options_and_redirect();
			}
			$message = $this->session_get('message', true);
			$options = $this->get_options();
			$plugin_url = $this->plugin_url;
			$save_url = $this->remove_query_arg(array());
			$preview_show_url = $this->admin_url('admin-ajax.php').'?action=agegate_preview';
			$preview_save_url = $this->admin_url('admin-ajax.php');
			$code_url = $this->admin_url('admin-ajax.php').'?action=agegate_code';
			include ($this->plugin_path.'settings_window.php');
		}
		
		function save_preview() {
			$options = $this->get_post_options();
			$this->session_set('preview', $options);
			die();
		}
		
		function show_preview() {
			$options = $this->session_get('preview');
			$plugin_url = $this->plugin_url;
			$is_preview = true;
			$countries = array();
			$cc = explode("\n", $options['minimum_age']);
			foreach($cc as $c) {
				$ca = explode(":", $c);
				$countries[] = array("age"=>$ca[0], "name" =>$ca[1]);
			}
			include ($this->plugin_path.'window.php');
			die();
		}
		
		function code() {
			$options = $this->get_options();
			include ($this->plugin_path.'code.php');
			die();
		}
		
		
		
		
		/* PLUGIN GENERAL FUNCTIONS ********************************************************************/
		
		function save_options_and_redirect() {
			$options = $this->get_post_options();
			$this->save_options($options);
			$url = ($_SERVER['HTTPS']!='on'?'http':'https').'://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
			$this->session_set('message', '<div class="updated">Your settings have been saved</div>');
			$this->redirect($url);
			//$message = '<div class="error">Un error</div>';
		}
		
		function save_options($options) {
			$fd = fopen($this->plugin_path.'/options.php','w');
			$str = "<?php\n";
			$str .= "\$options = array(\n";
			$str .= "  'enabled'        => ".($options['enabled']?"true":"false").",\n";
			$str .= "  'enabled_globally' => ".($options['enabled_globally']?"true":"false").",\n";
			$str .= "  'minimum_age'    => \"".$options['minimum_age']."\",\n";
			$str .= "  'redirect_url'   => \"".$options['redirect_url']."\",\n";
			$str .= "  'title'          => \"".$options['title']."\",\n";
			$str .= "  'text'           => \"".$options['text']."\",\n";
			$str .= "  'bottom_text'    => \"".$options['bottom_text']."\",\n";
			$str .= "  'width'          => ".$options['width'].",\n";
			$str .= "  'height'         => ".$options['height'].",\n";
			$str .= "  'window_color'   => \"".$options['window_color']."\",\n";
			$str .= "  'label_color'    => \"".$options['label_color']."\",\n";
			$str .= "  'text_color'     => \"".$options['text_color']."\",\n";
			$str .= "  'image_data'     => \"".$options['image_data']."\",\n";
			$str .= ");";
			fwrite($fd, $str);
			fclose($fd);
		}
		
		function get_options() {
			include($this->plugin_path.'options.php');
			//$options = get_option('agegate_options');
			$options['enabled'] = isset($options['enabled']) && $options['enabled'];
			$options['enabled_globally'] = isset($options['enabled_globally']) && $options['enabled_globally'];
			$options['minimum_age'] = isset($options['minimum_age'])?$options['minimum_age']:"21:USA\n18:Spain\n18:Others";
			$options['redirect_url'] = isset($options['redirect_url'])?$options['redirect_url']:'http://www.google.com';
			$options['title'] = isset($options['title'])?$options['title']:'Your title';
			$options['text'] = isset($options['text'])?stripslashes($options['text']):"Your text\nWith multiple lines.";
			$options['bottom_text'] = isset($options['bottom_text'])?stripslashes($options['bottom_text']):"";
			$options['width'] = isset($options['width'])?$options['width']:"600";
			$options['height'] = isset($options['height'])?$options['height']:"400";
			$options['window_color'] = isset($options['window_color'])?$options['window_color']:"#ffffff";
			$options['label_color'] = isset($options['label_color'])?$options['label_color']:"#005500";
			$options['text_color'] = isset($options['text_color'])?$options['text_color']:"#000000";
			if (!isset($options['image_data']) || $options['image_data']=='') {
				$options['image_data'] = $this->data_uri($this->plugin_path.'images/blank.png');
			}
			return $options;
		}
		
		
		function get_post_options() {
			$options = $this->get_options();
			if (isset($_POST['agegate_save_general_settings'])) {
				$options['enabled'] = isset($_POST['enabled'])?1:0;
				$options['enabled_globally'] = isset($_POST['enabled_globally'])?1:0;
				$options['minimum_age'] = $_POST['minimum_age'];
				$options['redirect_url'] = $_POST['redirect_url'];
				if (substr($options['redirect_url'],0,4)!='http') $options['redirect_url'] = 'http://'.$options['redirect_url'];
			}
			if (isset($_POST['agegate_save_window_settings'])) {
				$options['title'] = $_POST['title'];
				$options['text'] = stripslashes($_POST['text']);
				$options['bottom_text'] = stripslashes($_POST['bottom_text']);
				$options['width'] = isset($_POST['width'])?$_POST['width']:$options['width'];
				$options['height'] = isset($_POST['height'])?$_POST['height']:$options['height'];
				$options['window_color'] = isset($_POST['window_color'])?$_POST['window_color']:$options['window_color'];
				$options['label_color'] = isset($_POST['label_color'])?$_POST['label_color']:$options['label_color'];
				$options['text_color'] = isset($_POST['text_color'])?$_POST['text_color']:$options['text_color'];
				$options['image_data'] = (isset($_POST['image_data']) && $_POST['image_data']!='')?$_POST['image_data']:$options['image_data'];
			}
			return $options;
		}
		
		
		/* MISCELLANEOUS FUNCTIONS ********************************************************************/
		
		function session_get($name, $clear = false) {
			if (!isset($_SESSION['agegate'])) $_SESSION['agegate'] = array();
			$name = 'agegate_'.$name;
			$value = isset($_SESSION['agegate'][$name])?$_SESSION['agegate'][$name]:false;
			if ($clear) $this->session_unset('message');
			return $value;
		}
		
		function session_set($name, $value) {
			if (!isset($_SESSION['agegate'])) $_SESSION['agegate'] = array();
			$name = 'agegate_'.$name;
			$_SESSION['agegate'][$name] = $value;
		}
		
		function session_unset($name) {
			if (!isset($_SESSION['agegate'])) $_SESSION['agegate'] = array();
			$name = 'agegate_'.$name;
			$vars = $_SESSION['agegate'];
			$newvars = array();
			foreach($vars as $k=>$v) {
				if ($k != $name) $newvars[$k] = $v;
			}
			$_SESSION['agegate'] = $newvars;
		}
		
		function redirect($url) {
			if (!headers_sent()) {
				header('Location: '.$url); exit;
			} else {
				echo '<script type="text/javascript">';
				echo 'window.location.href="'.$url.'";';
				echo '</script>';
				echo '<noscript>';
				echo '<meta http-equiv="refresh" content="0;url='.$url.'" />';
				echo '</noscript>'; exit;
			}
			die();
		}

		function data_uri($file) 
		{  
			$info = getimagesize($file);
			$mime = image_type_to_mime_type($info[2]);
			$contents = file_get_contents($file);
			$base64   = base64_encode($contents); 
			return ('data:' . $mime . ';base64,' . $base64);
		}		
	}
	
	
}

?>